import cv2


def captureImg(filepath):
    camera = cv2.VideoCapture(0)
    return_value, image = camera.read()
    cv2.imwrite(filepath, image)
    del camera


def getImage():
    camera = cv2.VideoCapture(0)
    return_value, image = camera.read()
    del camera
    return image


def blur(image, intensity: tuple):
    blurred = cv2.GaussianBlur(image, intensity, cv2.BORDER_DEFAULT)
    return blurred


def blur2(image, intensity: int):
    blurred = cv2.GaussianBlur(image, (intensity, intensity), cv2.BORDER_DEFAULT)
    return blurred



import cv2


def bgr2Grayscale(image):
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    return gray


def grayscale2Bgr(image):
    return cv2.cvtColor(image, cv2.COLOR_GRAY2BGR)


def bgr2Hsv(image):
    return cv2.cvtColor(image, cv2.COLOR_BGR2HSV)


def hsv2Bgr(image):
    return cv2.cvtColor(image, cv2.COLOR_HSV2BGR)


def bgr2Rgb(image):
    return cv2.cvtColor(image, cv2.COLOR_BGR2RGB)


def rgb2Bgr(image):
    return cv2.cvtColor(image, cv2.COLOR_RGB2BGR)


def grayscale2Hsv(image):
    bgr = grayscale2Bgr(image)
    return bgr2Hsv(bgr)


def hsv2Grayscale(image):
    bgr = hsv2Bgr(image)
    return bgr2Grayscale(bgr)


def grayscale2Rgb(image):
    bgr = grayscale2Bgr(image)
    return bgr2Rgb(bgr)


def rgb2Grayscale(image):
    bgr = rgb2Bgr(image)
    return bgr2Grayscale(bgr)



from setuptools import setup, find_packages
import codecs
import os

VERSION = '1.5'
DESCRIPTION = 'OpenCV Plus'
LONG_DESCRIPTION = 'A package that gives you extra OpenCV functions.'

# Setting up
setup(
    name="open-cv-plus",
    version=VERSION,
    author="TheCoder1001 (Atharv Baluja)",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    keywords=['python', 'opencv'],
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
    ]
)



import cv2
import numpy as np


class ChannelChanger:
    def __init__(self, img):
        self.img = img
        self.b, self.g, self.r = cv2.split(img)

    def turnToRed(self):
        blank = np.zeros(self.img.shape[:2], dtype='uint8')
        return cv2.merge([blank, blank, self.r])

    def turnToGreen(self):
        blank = np.zeros(self.img.shape[:2], dtype='uint8')
        return cv2.merge([blank, self.g, blank])

    def turnToBlue(self):
        blank = np.zeros(self.img.shape[:2], dtype='uint8')
        return cv2.merge([self.b, blank, blank])
